Step
====

.. currentmodule:: pqp.refutation

.. autoclass:: Step
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Step.assume
      ~Step.explain
      ~Step.result
      ~Step.substep
      ~Step.write

   .. rubric:: Methods Documentation

   .. automethod:: assume
   .. automethod:: explain
   .. automethod:: result
   .. automethod:: substep
   .. automethod:: write
